import pluginCommonjs from '@rollup/plugin-commonjs'
import babel from '@rollup/plugin-babel'
import typescript from '@rollup/plugin-typescript';
import pluginJson from '@rollup/plugin-json'
import pluginImage from '@rollup/plugin-image'
import { nodeResolve } from '@rollup/plugin-node-resolve'
import { terser } from 'rollup-plugin-terser'
import { version } from './package.json'
import serve from 'rollup-plugin-serve'
import pluginLess from 'rollup-plugin-less';
import alias from '@rollup/plugin-alias';
import postcss from 'rollup-plugin-postcss';
import livereload from 'rollup-plugin-livereload';
const less = require('less');
const path = require("path");
const resolveDir = dir=>path.join(__dirname,dir);
const processLess = function(context, payload) {
  return new Promise(( resolve, reject ) => {
    less.render({
      file: context
    }, function(err, result) {
      if( !err ) {
        resolve(result);
      } else {
        reject(err);
      }
    });

    less.render(context, {})
    .then(function(output) {
      if( output && output.css ) {
        resolve(output.css);
      } else {
        reject({})
      }
    },
    function(err) {
      reject(err)
    });

  })
}
const OUTPUT_CONFIG = [
  {
    file: 'dist/index.js',
    name: 'umd',
    format: 'umd',
  },
  {
    file: 'dist/index.esm.js',
    name: 'esm',
    format: 'esm',
  }
].map((_i)=>{
  const {file, name, format} = _i;
  return {
    file, name, format,
    compact: true,
    exports: 'auto',
    sourcemap:true
    // banner:'/* version ' + version + 'a */',
    // footer:'/* follow me on github! @jingziX */',
  }
})
export default [
  {
    input: './src/index.js',
    sourcemap:true,
    external: ['react', 'react-dom'],
    globals:{
      react:'React',
      "react-dom":'ReactDOM'
    },
    output: OUTPUT_CONFIG,
    plugins: [
      babel({
        exclude: ['node_modules/**'],
      }),
      pluginImage({
        exclude: ['node_modules/**'],
      }),
      nodeResolve({
        preferBuiltins: true,
        browser: true,
      }),
      pluginCommonjs(),
      pluginJson(),
      // terser(), //代码压缩1
      typescript(),
      pluginLess(),
      serve({
        open:true,
        port:8888,
        contentBase:''
      }),
      livereload(),
      // postcss(),
      // postcss({
      //   extract: true,
      //   minimize: false,
      //   process: processLess
      // }),
      alias({
        entries: [
          { find: '@', replacement: resolveDir('src') },
          { find: '@u', replacement: resolveDir('src/utils') }
        ]
      })
    ],
    // cache: true,
  }
]
