import { Base64 } from 'js-base64';
const GLOBAL_ENV = 'prod';
/** 6国翻译,来自cj common文件夹 */
export const languages = ['zh', 'en', 'de', 'fr', 'id', 'th'];

/** 根据子域名获取CJ的父域名  web端 */
export const getWebsite = function () {
  const environment = GLOBAL_ENV;
  const { host } = window.location;
  const hostArr = host.split('.');
  const lastHostName = hostArr[hostArr.length - 1];
  let website = '';
  if (environment === 'prod') {
    if (lastHostName === 'com') {
      website = `https://cjdropshipping.${lastHostName}`;
    } else {
      website = `https://app.cjdropshipping.${lastHostName}`;
    }
  }
  if (environment !== 'prod') {
    website = 'http://app.test.com';
  }
  return website;
};

/** 根据子域名获取CJ的父域名 M站 */
export const getWebsiteM = function () {
  const environment = GLOBAL_ENV;
  const { host } = window.location;
  const hostArr = host.split('.');
  const lastHostName = hostArr[hostArr.length - 1];
  let website = '';
  if (environment === 'prod') {
    website = `https://m.cjdropshipping.${lastHostName}`;
  }
  if (environment !== 'prod') {
    website = 'http://m.test.com';
  }
  return website;
};

/**
 * 获取路由参数
 * @params props 页面参数
 */
export const getRouteParams = (props: any) => props.location.state || {};

/* 
 * 获取顶级域名
 */
export const getTopDomain = (host = location.hostname) => {
  const ipPattPern = /^\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}$/; // 匹配ip
  if (ipPattPern.test(host)) {
    return host;
  }
  const tmp = host.split('.');
  let domain = '';
  if (tmp.length > 1) {
    const last = tmp.length - 1;
    domain = `${tmp[last - 1]}.${tmp[last]}`;
  } else {
    domain = host;
  }
  return `.${domain}`;
};
/**
 * 获取cookie
 * @params cookieName cookie名称
 */
export const getCookie = (cookieName: string) => {
  if (document.cookie.length > 0) {
    let start = document.cookie.indexOf(`${cookieName}=`);
    if (start !== -1) {
      start = start + cookieName.length + 1;
      let end = document.cookie.indexOf(';', start);
      if (end === -1) end = document.cookie.length;
      return document.cookie.substring(start, end);
    }
  }
  return '';
};

export function delCookie(name: string) {
  const { host } = window.location;
  const domain = getTopDomain();
  const exp = new Date();
  exp.setDate(exp.getDate() - 1);
  const cval = getCookie(name);
  if (cval != null) {
    document.cookie = `${name}=${cval};expires=${exp.toUTCString()};path=/;domain=.${domain}`; // 清掉主域cookie
    document.cookie = `${name}=${cval};expires=${exp.toUTCString()};path=/;domain=${host}`; // 清掉子域cookie
    document.cookie = `${name}=${cval};expires=${exp.toUTCString()};path=/;`; // 清掉子域cookie
  }
}

export function setCookie(name: string, value: string) {
  const domain = getTopDomain(); 

  const exp = new Date();
  exp.setDate(exp.getDate() + 7);
  if (process.env.NODE_ENV === 'development') {
    document.cookie = `${name}=${value};expires=${exp.toUTCString()};path=/`; // 设置主域cookie
  } else {
    delCookie(name);
    document.cookie = `${name}=${value};expires=${exp.toUTCString()};path=/;domain=.${domain}`; // 设置主域cookie
  }
}

/**
 * 价格根据汇率切换
 * price价格
 * unit汇率
 * symbol符号
 */

export const translatePrice = (price: string, unit: number) => {
  if (!price) return [];
  if (price.indexOf('--') > -1) {
    const priceArr = price.split('--');
    const min = (unit * Number(priceArr[0])).toFixed(2);
    const max = (unit * Number(priceArr[1])).toFixed(2);
    return [min, max];
  } else if (price.indexOf('-') > -1) {
    const priceArr = price.split('-');
    const min = (unit * Number(priceArr[0])).toFixed(2);
    const max = (unit * Number(priceArr[1])).toFixed(2);
    return [min, max];
  } else {
    const priceSingle = (unit * Number(price)).toFixed(2);
    return [priceSingle];
  }
};

/** 参数拼接 */
export const getParams = (query: any) => {
  if (!query) return;
  const value = Object.keys(query).reduce((cur, pre) => {
    if (query[pre]) {
      if (pre === 'sortByParam') {
        // 这里做特殊处理
        // cur += `&${pre}=${JSON.stringify(query[pre])}`;
        cur += `&sortFieldType=${query[pre].feildType}&sortAsc=${query[pre].isAsc}`;
      } else {
        cur += `&${pre}=${query[pre]}`;
      }
    }
    return cur;
  }, '');
  return value.slice(1);
};
/** 地址参数解析 输出的是一个数组 */
export const analysisParams = () => {
  const params = window.location.search.substring(1);
  return params.split('&').map((item) => {
    const index = item.indexOf('=');
    if (index == -1) {
      return {
        [item]: null,
      };
    }
    const key = item.slice(0, index);
    const val = item.slice(index + 1);
    return {
      [key]: val,
    };
  });
};

function createStorage(storage: Storage) {
  return {
    storage, // 不能换成sessionStorage
    get(key: string) {
      const data: string | any = this.storage.getItem(key);
      if (!data) return data;
      let parseData;
      try {
        parseData = JSON.parse(data);
      } catch {
        parseData = data;
      }
      return parseData;
    },
    set(key: string, val: any) {
      const v: string = typeof val === 'string' ? val : JSON.stringify(val);
      this.storage.setItem(key, v);
    },
    remove(key: string | Array<string>) {
      if (typeof key === 'string') {
        this.storage.removeItem(key);
      } else {
        try {
          key.map((k: string) => this.storage.removeItem(k));
        } catch {
          console.log('传入的格式不正确');
        }
      }
    },
  };
}

/** localStorage存储 */
export const lStorage = createStorage(localStorage);

/** sessionStorage存储 */
export const sStorage = createStorage(sessionStorage);

export function transLan(lan: string, googtrans: string) {
  const isSixCountryTrans = languages.includes(lan); // 是否是6国翻译
  if (isSixCountryTrans) {
    delCookie('googtrans');
    window.location.reload();
  } else {
    (window as any).doGTranslate && (window as any).doGTranslate(googtrans);
  }
}

/** 检查是否已登录 */
export const checkLogin = () => {
  const token = lStorage.get('token');
  return !!token;
};

/**
 * 处理oss图片
 * @param url img 地址
 * @param size 图片尺寸
 */
export function handleOssImg(url: string, w = 40, h = 40) {
  let res = url || '';
  if (url.includes('aliyuncs.com') && !url.includes('/resize,')) {
    // 已经压缩过的就再进行压缩
    res = `${url}?x-oss-process=image/resize,w_${w},h_${h}`;
  }
  return res;
}
/**
 * 获取地址栏参数
 * */
export function getQueryVariable(nameString: string) {
  const query = window.location.search.substring(1);
  const vars = query.split('&');
  for (let i = 0; i < vars.length; i++) {
    const pair = vars[i].split('=');
    if (pair[0] === nameString) {
      return pair[1];
    }
  }
  return false;
}
/**
 * 添加mate标签
 * */
export function addMeta(metaObj: any = {}) {
  const metaDom: any = document.createElement('meta');
  for (let key in metaObj) {
    metaDom.setAttribute(key, metaObj[key]);
  }
  const parent = document.getElementsByTagName('head')[0];
  parent.insertBefore(metaDom, parent.childNodes[0]);
}
/**
 * 未登录状态跳转cj登录页
 * */
export function goCjLogin(backUrl: string, isNewOpen = false) {
  let url = '';
  if (GLOBAL_ENV === 'prod') {
    // 表示线上环境
    url = `https://cjdropshipping.com/login.html?target=${Base64.encode(
      backUrl,
    )}`;
  } else {
    url = `http://app.test.com/login.html?target=${Base64.encode(backUrl)}`;
  }
  if (isNewOpen) window.open(url);
  if (!isNewOpen) window.location.href = url;
}
